@@ -5,4 +5,7 @@ mod key;
 mod onion;
 
 #[cfg(feature = "serialize")]
-mod serde;
\ No newline at end of file
+mod serde_key;
+
+#[cfg(feature = "serialize")]
+mod serde_onion;
\ No newline at end of file
